Sensors class

Expresses the presence of detected motion-related sensors of the device.

See BackgroundGeolocation.sensors.

Constructors

Sensors(Map data)

Properties

accelerometer ↔ bool
true if this device has an accelerometer.
getter/setter pair
gyroscope ↔ bool
true if this device has a gyroscope.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
magentometer → bool
@deprecated Misspelled. Use magnetometer.
no setter
magnetometer ↔ bool
true if this device has a magnetometer (compass).
getter/setter pair
motionHardware ↔ bool?
[iOS only] true if this iOS device has an M7 co-processor (iPhone 5S+).
getter/setter pair
platform ↔ String
Device platform ios | android.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
significantMotion ↔ bool?
[Android only] true if this Android device has a "significant motion" sensor.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited